@@ -24,7 +24,6 @@ from .fun_win import find_software_install_path
 from .fun_base import log, hostname, send_exception
 from .fun_file import check_progress_json_ex, get_progress_json_ex, done_progress_json_ex, write_dict_to_file_ex
 
-
 class ZiniaoClient:
     """紫鸟客户端管理类"""
 
@@ -53,7 +52,7 @@ class ZiniaoClient:
     def _get_user_info(self) -> Dict[str, str]:
         """获取用户登录信息"""
         return {
-            "company": self.config.ziniao.company,
+            "company" : self.config.ziniao.company,
             "username": self.config.ziniao.username,
             "password": self.config.ziniao.password
         }
@@ -90,7 +89,7 @@ class ZiniaoClient:
     def update_core(self):
         """下载所有内核，打开店铺前调用，需客户端版本5.285.7以上"""
         data = {
-            "action": "updateCore",
+            "action"   : "updateCore",
             "requestId": str(uuid.uuid4()),
         }
         data.update(self.user_info)
@@ -146,7 +145,6 @@ class ZiniaoClient:
         print('@@ get_exit...' + json.dumps(data))
         self.send_http(data)
 
-
 class ZiniaoBrowser:
     """紫鸟浏览器操作类"""
 
@@ -155,22 +153,22 @@ class ZiniaoBrowser:
         self.config = config
 
     def open_store(self, store_info: str, isWebDriverReadOnlyMode: int = 0,
-                   isprivacy: int = 0, isHeadless: int = 0,
-                   cookieTypeSave: int = 0, jsInfo: str = "") -> Dict[str, Any]:
+            isprivacy: int = 0, isHeadless: int = 0,
+            cookieTypeSave: int = 0, jsInfo: str = "") -> Dict[str, Any]:
         """打开店铺"""
         request_id = str(uuid.uuid4())
         data = {
-            "action": "startBrowser",
-            "isWaitPluginUpdate": 0,
-            "isHeadless": isHeadless,
-            "requestId": request_id,
+            "action"                 : "startBrowser",
+            "isWaitPluginUpdate"     : 0,
+            "isHeadless"             : isHeadless,
+            "requestId"              : request_id,
             "isWebDriverReadOnlyMode": isWebDriverReadOnlyMode,
-            "cookieTypeLoad": 0,
-            "cookieTypeSave": cookieTypeSave,
-            "runMode": "1",
-            "isLoadUserPlugin": False,
-            "pluginIdType": 1,
-            "privacyMode": isprivacy
+            "cookieTypeLoad"         : 0,
+            "cookieTypeSave"         : cookieTypeSave,
+            "runMode"                : "1",
+            "isLoadUserPlugin"       : False,
+            "pluginIdType"           : 1,
+            "privacyMode"            : isprivacy
         }
         data.update(self.client.user_info)
 
@@ -196,9 +194,9 @@ class ZiniaoBrowser:
         """关闭店铺"""
         request_id = str(uuid.uuid4())
         data = {
-            "action": "stopBrowser",
-            "requestId": request_id,
-            "duplicate": 0,
+            "action"      : "stopBrowser",
+            "requestId"   : request_id,
+            "duplicate"   : 0,
             "browserOauth": browser_oauth
         }
         data.update(self.client.user_info)
@@ -213,11 +211,11 @@ class ZiniaoBrowser:
             print(f"Fail {json.dumps(r, ensure_ascii=False)} ")
             raise RuntimeError("关闭店铺失败")
 
-    def get_browser_list(self) -> List[Dict[str, Any]]:
+    def get_browser_list(self, platform_name="SHEIN-全球") -> List[Dict[str, Any]]:
         """获取浏览器列表"""
         request_id = str(uuid.uuid4())
         data = {
-            "action": "getBrowserList",
+            "action"   : "getBrowserList",
             "requestId": request_id
         }
         data.update(self.client.user_info)
@@ -225,7 +223,8 @@ class ZiniaoBrowser:
         r = self.client.send_http(data)
         if str(r.get("statusCode")) == "0":
             print(r)
-            return r.get("browserList", [])
+            # return r.get("browserList", [])
+            return [site for site in r.get("browserList", []) if site.get("platform_name") == platform_name]
         elif str(r.get("statusCode")) == "-10003":
             print(f"login Err {json.dumps(r, ensure_ascii=False)}")
             raise RuntimeError("登录错误")
@@ -267,7 +266,6 @@ class ZiniaoBrowser:
         # 标记完成
         done_progress_json_ex(self.config, task_key, store_name)
 
-
 class ZiniaoTaskManager:
     """紫鸟任务管理类"""
 
@@ -276,10 +274,10 @@ class ZiniaoTaskManager:
         self.config = config
 
     def run_single_store_task(self, browser_info: Dict[str, Any],
-                              run_func: Callable, task_key: str,
-                              just_store_username: Optional[List[str]] = None,
-                              is_skip_store: Optional[Callable] = None
-                              ):
+            run_func: Callable, task_key: str,
+            just_store_username: Optional[List[str]] = None,
+            is_skip_store: Optional[Callable] = None
+    ):
         """运行单个店铺的任务"""
         retry_count = 0
         while True:
@@ -350,20 +348,20 @@ class ZiniaoTaskManager:
                     break
 
     def run_all_stores_task(self, browser_list: List[Dict[str, Any]],
-                            run_func: Callable, task_key: str,
-                            just_store_username: Optional[List[str]] = None,
-                            is_skip_store: Optional[Callable] = None
-                            ):
+            run_func: Callable, task_key: str,
+            just_store_username: Optional[List[str]] = None,
+            is_skip_store: Optional[Callable] = None
+    ):
         """循环运行所有店铺的任务"""
         for browser_info in browser_list:
             self.run_single_store_task(browser_info, run_func, task_key, just_store_username, is_skip_store)
 
     def run_with_thread_pool(self, browser_list: List[Dict[str, Any]],
-                             max_threads: int = 3, run_func: Callable = None,
-                             task_key: str = None,
-                             just_store_username: Optional[List[str]] = None,
-                             is_skip_store: Optional[Callable] = None
-                             ):
+            max_threads: int = 3, run_func: Callable = None,
+            task_key: str = None,
+            just_store_username: Optional[List[str]] = None,
+            is_skip_store: Optional[Callable] = None
+    ):
         """使用线程池控制最大并发线程数运行任务"""
         with ThreadPoolExecutor(max_workers=max_threads) as executor:
             task = partial(self.run_single_store_task,
@@ -373,7 +371,6 @@ class ZiniaoTaskManager:
             log(f'店铺总数: {len(browser_list)}')
             executor.map(task, browser_list)
 
-
 class ZiniaoRunner:
     """紫鸟主运行器类"""
 
@@ -387,13 +384,14 @@ class ZiniaoRunner:
         self.task_manager = ZiniaoTaskManager(self.browser, config)
 
     def execute(self, run_prepare: Optional[Callable] = None,
-                run: Optional[Callable] = None,
-                run_summary: Optional[Callable] = None,
-                run_notify: Optional[Callable] = None,
-                task_key: Optional[str] = None,
-                just_store_username: Optional[List[str]] = None,
-                is_skip_store: Optional[Callable] = None,
-                ):
+            run: Optional[Callable] = None,
+            run_summary: Optional[Callable] = None,
+            run_notify: Optional[Callable] = None,
+            task_key: Optional[str] = None,
+            just_store_username: Optional[List[str]] = None,
+            is_skip_store: Optional[Callable] = None,
+            platform_name: Optional[str] = "SHEIN-全球",
+    ):
         """主执行入口"""
         # 前置执行 if run_prepare:
         run_prepare()
@@ -408,7 +406,7 @@ class ZiniaoRunner:
 
         # 获取店铺列表
         print("=====获取店铺列表=====")
-        browser_list = self.browser.get_browser_list()
+        browser_list = self.browser.get_browser_list(platform_name=platform_name)
         if not browser_list:
             print("browser list is empty")
             raise RuntimeError("店铺列表为空")
@@ -445,6 +443,5 @@ class ZiniaoRunner:
         # 关闭客户端
         self.client.exit()
 
-
 if __name__ == "__main__":
     pass
